..
      Copyright 2011 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

===================
Glance Installation
===================

.. toctree::

   get-started
   install.rst
   verify.rst


Supported Releases
==================

Queens (Latest Release)
~~~~~~~~~~~~~~~~~~~~~~~

To install Glance, see the Queens Image service install guide for
each distribution:

- `Ubuntu <https://docs.openstack.org/glance/queens/install/install-debian.html>`__
- `CentOS and RHEL <https://docs.openstack.org/glance/queens/install/install-rdo.html>`__
- `openSUSE and SUSE Linux Enterprise <https://docs.openstack.org/glance/queens/install/install-obs.html>`__

Pike (Maintained Release)
~~~~~~~~~~~~~~~~~~~~~~~~~

To install Glance, see the Pike Image service install guide for
each distribution:

- `Ubuntu <https://docs.openstack.org/glance/pike/install/install-debian.html>`__
- `CentOS and RHEL <https://docs.openstack.org/glance/pike/install/install-rdo.html>`__
- `openSUSE and SUSE Linux Enterprise <https://docs.openstack.org/glance/pike/install/install-obs.html>`__

Ocata (Legacy Release)
~~~~~~~~~~~~~~~~~~~~~~

To install Glance, see the `Ocata Image service install guide`_.

.. _`Ocata Image service install guide`: https://docs.openstack.org/glance/ocata/installing.html
